==> cloud-8.x-1.0-beta1.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Controller/Ec2/KeyPairAccessControlHandler.php <==
<?php


// Updated by yas 2016/05/23
// updated by yas 2016/05/20
// created by yas 2016/05/19.
namespace Drupal\aws_cloud\Controller\Ec2;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the KeyPair entity.
 *
 * @see \Drupal\aws_cloud\Entity\Ec2\KeyPair\Entity\KeyPair.
 */
class KeyPairAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermissions($account, ['view aws cloud key pair', 'view ' . $entity->cloud_context()]);
      case 'update':
      case 'edit':
        return AccessResult::allowedIfHasPermissions($account, ['edit aws cloud key pair', 'view ' . $entity->cloud_context()]);

      case 'delete':
        return AccessResult::allowedIfHasPermissions($account, ['delete aws cloud key pair', 'view ' . $entity->cloud_context()]);
    }
    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * Not being used anymore.  Access check is performed in \Drupal\cloud\Controller\CloudConfigController::access
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add aws cloud key pair');
  }

}

==> cloud-8.x-1.1-beta1.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Controller/Ec2/KeyPairAccessControlHandler.php <==
<?php

// Updated by yas 2016/05/23
// updated by yas 2016/05/20
// created by yas 2016/05/19.
namespace Drupal\aws_cloud\Controller\Ec2;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the KeyPair entity.
 *
 * @see \Drupal\aws_cloud\Entity\Ec2\KeyPair\Entity\KeyPair.
 */
class KeyPairAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermissions($account, ['view aws cloud key pair', 'view ' . $entity->getCloudContext()]);

      case 'update':
      case 'edit':
        return AccessResult::allowedIfHasPermissions($account, ['edit aws cloud key pair', 'view ' . $entity->getCloudContext()]);

      case 'delete':
        return AccessResult::allowedIfHasPermissions($account, ['delete aws cloud key pair', 'view ' . $entity->getCloudContext()]);
    }
    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * Not being used anymore.
   *
   * Access check is performed in \Drupal\cloud\Controller\CloudConfigController::access.
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add aws cloud key pair');
  }

}
